pub struct ParserPool<'r> { /* private fields */ }Expand description
Lazily initialized parser and query cache for a language registry.
Implementations
Sourceimpl<'r> ParserPool<'r>
impl<'r> ParserPool<'r>
Sourcepub fn new(registry: &'r LanguageRegistry) -> Self
pub fn new(registry: &'r LanguageRegistry) -> Self
Creates an empty cache backed by registry.
Sourcepub fn parser(&mut self, id: LanguageId) -> Option<&mut Parser>
pub fn parser(&mut self, id: LanguageId) -> Option<&mut Parser>
Returns a parser for id, creating and configuring it on first use.
A grammar rejected by tree-sitter is cached as a permanent miss.
Returns the compiled tags query for id.
Missing query sources and compilation failures are cached permanently.
Sourcepub fn imports_query(&mut self, id: LanguageId) -> Option<&Query>
pub fn imports_query(&mut self, id: LanguageId) -> Option<&Query>
Returns the compiled query-based import extractor for id.
Custom extractors, missing queries, and compilation failures are cached as permanent misses.
Sourcepub fn injections_query(&mut self, id: LanguageId) -> Option<&Query>
pub fn injections_query(&mut self, id: LanguageId) -> Option<&Query>
Returns the compiled injection query for id.
Missing query sources and compilation failures are cached permanently.