pub trait SourceLoader: Sync {
// Required methods
fn verify(&self) -> Result<(), String>;
fn probe(&self, path: &str) -> Option<u64>;
fn load(&self, path: &str) -> Option<String>;
}Expand description
Source access supplied by the host that owns the repository or file store.
The index-build driver performs all source access through this trait and never reads the filesystem directly.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".